Adverse Events Plugin Server
Usage
mod_AE_Server(
id,
dfAnalyticsInput,
dfResults,
rctv_dSnapshotDate,
rctv_dfAE_Study,
rctv_strGroupID,
rctv_strGroupLevel,
rctv_strSubjectID,
chrCategoricalFields = c(aeser = "Serious?", mdrpt_nsv = "Preferred Term", mdrsoc_nsv =
"System Organ Class", aetoxgr = "Toxicity Grade", aeongo = "Ongoing?", aerel =
"Related?"),
chrDateFields = c(mincreated_dts = "AE Entry Date", aest_dt = "AE Start Date", aeen_dt
= "AE End Date"),
chrMetricID_AE = c(Site = "Analysis_kri0001", Country = "Analysis_cou0001"),
chrMetricID_SAE = c(Site = "Analysis_kri0002", Country = "Analysis_cou0002")
)Arguments
- id
characterThe id for this element.- dfAnalyticsInput
data.frameParticipant-level metric data.- dfResults
data.frameA stacked summary of analysis pipeline output.- rctv_dSnapshotDate
reactive DateAshiny::reactive()object that returns the date of a data snapshot.- rctv_dfAE_Study
reactive dataframeAshiny::reactive()object that returns a study-level adverse events domain dataframe.- rctv_strGroupID
reactive characterAshiny::reactiveVal()object that returns theGroupIDof the selected group (usually site), and can be used to update which group is selected.- rctv_strGroupLevel
reactive characterAshiny::reactiveVal()object that returns the selectedGroupLevel.- rctv_strSubjectID
reactive characterAshiny::reactive()object that returns theSubjectIDof the selected participant.- chrCategoricalFields
characterA named vector of fields indfAEto treat as categorical, where the names are the column names and the values are what to display to users. Unnamed elements will be used as both the field name and the display name. These fields are currently used in the Prevalence panel.- chrDateFields
characterA named vector of fields indfAEto treat as dates, where the names are the column names and the values are what to display to users. Unnamed elements will be used as both the field name and the display name. These fields are currently used in the Timeline panel.- chrMetricID_AE
characterThe ID(s) of the adverse events metric(c). The default value is named byGroupLevel, but the names are not currently used. It is advisable to only provide oneMetricIDperGroupLevel, though.- chrMetricID_SAE
characterThe ID(s) of the serious adverse events metric(s). The default value is named byGroupLevel, but the names are not currently used. It is advisable to only provide oneMetricIDperGroupLevel, though.