Adverse Events Plugin UI
Usage
mod_AE_UI(
id,
chrCategoricalFields = c(aeser = "Serious?", mdrpt_nsv = "Preferred Term", mdrsoc_nsv =
"System Organ Class", aetoxgr = "Toxicity Grade", aeongo = "Ongoing?", aerel =
"Related?"),
chrDateFields = c(mincreated_dts = "AE Entry Date", aest_dt = "AE Start Date", aeen_dt
= "AE End Date")
)Arguments
- id
characterThe id for this element.- chrCategoricalFields
characterA named vector of fields indfAEto treat as categorical, where the names are the column names and the values are what to display to users. Unnamed elements will be used as both the field name and the display name. These fields are currently used in the Prevalence panel.- chrDateFields
characterA named vector of fields indfAEto treat as dates, where the names are the column names and the values are what to display to users. Unnamed elements will be used as both the field name and the display name. These fields are currently used in the Timeline panel.
Value
A bslib::page_fillable() with the AE plugin UI.